from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description=fh.read()
    
setup(name='kasver',
      version='0.0.1',
      packages=find_packages(),
      install_requires=[],
      author='Kasver Math',
      description='Utilidades personales.',
      long_description=long_description,
      long_description_content_type="text/markdown",
      url='https://carlosvas.dev',
)



#!/bin/env python3

import subprocess

def send_public_ip():
    ip = subprocess.run(['curl', 'ifconfig.me'], capture_output=True, text=True)
    subprocess.run([
        'curl', '-X', 'POST',
        'https://karlosvas-api.carlosvassan.workers.dev/ip',
        '-H', 'Content-Type: application/json',
        '-d', f'{{"ip": "{ip.stdout.strip()}"}}'
    ])
    print(ip.stdout)

if __name__ == "__main__":
    send_public_ip()
